package com.trainerplan.trainerplan;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.facebook.stetho.Stetho;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;


// Esta clase nos permite validar un usuario en el servidor y guarda los datos de forma persistente para que el usuario realice
// acciones como el compartir planes con otros usuarios.

public class Validar extends AppCompatActivity {


    private String emailtxt, passwordtxt;
    private EditText email, password;

    //Nos permite almacenar de forma persistentes los datos de los usuarios
    SharedPreferences prefs;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_validar);


        // Inicializamos los datos que posteriormente vamos a guardar de forma persistente.
        prefs = getSharedPreferences("MisPreferencias",Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = prefs.edit();
        editor.putString("urlbase", "https://www.trainerplan.com/app/");
        //editor.putString("urlbase", "http://192.168.1.131:8080/trainerplan/");

        editor.putString("idrespuesta", "");
        editor.putString("email", "");
        editor.putString("idusuario", "");
        editor.putString("sesion", "");
        editor.commit();


        // Inicializamos stetho para poder ver la BBDD desde chrome://inspect
        Stetho.initializeWithDefaults(this);


        Button entrar = (Button) findViewById(R.id.entrar);
        Button registrar = (Button) findViewById(R.id.registrar);
        Button sinregistrar = (Button) findViewById(R.id.entrarsin);


        email = (EditText) findViewById(R.id.email);
        password = (EditText) findViewById(R.id.password);



        entrar.setBackgroundColor(Color.RED);
        entrar.setFocusableInTouchMode(true);
        entrar.requestFocus();



        // Cuando pulsamos sobre el botón entrar realizamos una validación de los datos si estos son correctos enviamos un POST al servidor
        // Nos devuelve un json con los resultados del mismo
        entrar.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View view) {


                emailtxt=email.getText().toString();
                passwordtxt=password.getText().toString();

                if (emailtxt.isEmpty()) {
                    email.requestFocus();
                    Toast.makeText(Validar.this, getString(R.string.email_obligatorio), Toast.LENGTH_SHORT).show();
                } else if (passwordtxt.isEmpty()) {
                    password.requestFocus();
                    Toast.makeText(Validar.this, getString(R.string.password_obligatorio), Toast.LENGTH_SHORT).show();

                } else if (!android.util.Patterns.EMAIL_ADDRESS.matcher(emailtxt).matches()) {
                    Toast.makeText(Validar.this, getString(R.string.correo_no_valido), Toast.LENGTH_SHORT).show();
                    email.requestFocus();
                } else {

                    if (new CheckearConexion(Validar.this).isNetworkAvailable()) {
                        // Obtenemos la url base
                        SharedPreferences prefs = getSharedPreferences("MisPreferencias", Context.MODE_PRIVATE);
                        String urlbase;
                        urlbase = (prefs.getString("urlbase", ""));
                        Validar.validarUsuario obtenerplan = new Validar.validarUsuario(Validar.this);
                        obtenerplan.execute(urlbase+"validacion.php", emailtxt, passwordtxt);

                    } else {
                         Toast.makeText(Validar.this, getString(R.string.error_conexion), Toast.LENGTH_LONG).show();
                    }


                }


            }

        });



        registrar.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View view) {
                Intent intent = new Intent(Validar.this, Registro.class);
                startActivity(intent);
            }

        });


        sinregistrar.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View view) {
                Intent intent = new Intent(Validar.this, Planes.class);
                startActivity(intent);
            }

        });




    }



    public class validarUsuario extends AsyncTask<String, String, String> {


        //Bara de progresión
        private ProgressDialog dialog;


        public validarUsuario (Validar activity) {

            // Definimos la barra de progresión
            dialog = new ProgressDialog(activity);


        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            // Mostramos la barra de progresión
            dialog.setMessage(getString(R.string.validando_usuario));
            dialog.show();
        }

        @Override
        protected String doInBackground(String... params) {

            String urlString = params[0]; // URL to call

            String resultToDisplay = "";
            OutputStreamWriter request = null;

            String respuesta;

            InputStream in = null;
            try {

                URL url = new URL(urlString);
                String parameters = "email="+params[1]+"&password="+params[2];


                HttpURLConnection urlConnection = (HttpURLConnection) url.openConnection();
                urlConnection.setDoOutput(true);
                urlConnection.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
                urlConnection.setRequestMethod("POST");

                request = new OutputStreamWriter(urlConnection.getOutputStream());
                request.write(parameters);
                request.flush();
                request.close();



                in = new BufferedInputStream(urlConnection.getInputStream());

                BufferedReader br = new BufferedReader(new InputStreamReader(in));
                String inputLine = "";
                while ((inputLine = br.readLine()) != null) {
                    resultToDisplay+=inputLine;

                }

                respuesta = trataJSON(resultToDisplay);


            } catch (Exception e) {

                System.out.println(e.getMessage());

                return e.getMessage();

            }

            return respuesta;


        }


        @Override
        protected void onPostExecute(String result) {

            // Finalizamos la barra de progresión
            if (dialog.isShowing()) {
                dialog.dismiss();
            }



            if (result.equals("0")) {
                Toast.makeText(getBaseContext(),getString(R.string.usuario_incorrecto), Toast.LENGTH_LONG).show();

            } else  if (result.equals("2")) {
                Toast.makeText(getBaseContext(), getString(R.string.cuenta_no_activada), Toast.LENGTH_LONG).show();
            }
            else if (!result.equals("1")) {
                Toast.makeText(Validar.this, getString(R.string.error_conexion_servidor)+" "+ result, Toast.LENGTH_LONG).show();

            }
        }
    }


    // Nos permite obtener el json, si es correcto almacenamos de forma persistente el correo, idusuario, session.
    private String trataJSON(String result) {

        String idrespuesta="", respuesta="", email="", sesion="";
        Integer idusuario=0;

        JSONArray jsonArray = null;
        try {
            jsonArray = new JSONArray(result);
            for (int i = 0; i < jsonArray.length(); i++) {
                JSONObject obj1 = jsonArray.getJSONObject(i);
                 idrespuesta = (String) obj1.get("idrespuesta");
                 respuesta = (String) obj1.get("respuesta");
                 email = (String) obj1.get("email");
                 sesion = (String) obj1.get("sesion");
                 idusuario = (Integer) obj1.get("idusuario");
            }


            if (idrespuesta.equals("1")) {

                SharedPreferences prefs = getSharedPreferences("MisPreferencias",Context.MODE_PRIVATE);
                SharedPreferences.Editor editor = prefs.edit();
                editor.putString("idrespuesta", idrespuesta.trim());
                editor.putString("email", email.trim());
                editor.putString("idusuario", idusuario.toString().trim());
                editor.putString("sesion", sesion.trim());
                editor.commit();


                String correo = prefs.getString("email","");

                Intent intent = new Intent(Validar.this, Planes.class);
                startActivity(intent);
            }

        } catch (JSONException e) {
            e.printStackTrace();
        }

        return idrespuesta;

    }



}
